﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Xml;

namespace vcPlugin
{
    /// <summary>
    /// options will be loaded automatically when this is created
    /// </summary>
    public class pluginOptions
    {
        //define varialbe to hold the options you need to keep track of here
        public string textSetting1;
        public Int32 numSetting1;
        
        
        //this is used to load and save options to the correct folder
        private string strPluginPath;

        public pluginOptions()
        {
            //set default values
            textSetting1 = "255.255.255.255";
            numSetting1 = 54000;
        
            
            //find the correct folder and store it for later use by the load and save methods
            strPluginPath = System.IO.Path.GetDirectoryName(System.Reflection.Assembly.GetExecutingAssembly().Location) + "\\Options.xml";
            if (System.IO.File.Exists(strPluginPath))
            { loadOptionsFromXml(); }
        }

        /// <summary>
        /// saves all our options
        /// must create a case for each value to load
        /// </summary>
        public void loadOptionsFromXml()
        {
            XmlDocument myXmlDocument = new XmlDocument();
            myXmlDocument.Load(strPluginPath);

            XmlNode rootnode;
            XmlNode nextnode;
            rootnode = myXmlDocument.DocumentElement;
            nextnode = rootnode.NextSibling;

            foreach (XmlNode majorNode in rootnode.SelectNodes("Option"))
            {
                string minorNodeName = majorNode.Attributes["name"].Value;
                string minorNodeValue = majorNode.Attributes["value"].Value;
                switch (majorNode.Attributes["name"].Value)
                {
                    case "defaultIP":
                        textSetting1 = minorNodeValue;                        
                        break;
                    case "defaultPort":
                        numSetting1 =Convert.ToInt32( minorNodeValue);
                        break;
                    
                        //
                    default:
                        break;
                }
            }

            myXmlDocument = null;
        }

        public void saveOptionsToXml()
        {
            // Create the XML document and write the comments and root node "AllOptions"
            XmlTextWriter writer = new XmlTextWriter(strPluginPath, new System.Text.ASCIIEncoding());
            writer.Formatting = Formatting.Indented;
            writer.Indentation = 4;
            writer.WriteStartDocument();
            writer.WriteComment("options for VoxCommando / <plugin name goes here>.");

            writer.WriteStartElement("Options");
            {
                saveOptionNodeToXml(writer, "defaultIP", textSetting1);
                saveOptionNodeToXml(writer, "defaultPort", numSetting1.ToString());                
            }
            writer.WriteEndElement();


            #region Close Up the XML document
            //counterpart to WriteStartDocument command
            writer.WriteEndDocument();
            writer.Flush();
            writer.Close();
            #endregion
        }

        private void saveOptionNodeToXml(XmlTextWriter writer, string nodename, string nodevalue)
        {
            writer.WriteStartElement("Option");
            writer.WriteAttributeString("name", nodename);
            writer.WriteAttributeString("value", nodevalue);
            writer.WriteEndElement();
        }
    }
}
